@@ -11,6 +11,8 @@
 #include "umlwidget.h"
 
 // local includes
+#include "actor.h"
+#include "actorwidget.h"
 #include "associationwidget.h"
 #include "classifier.h"
 #include "classpropertiesdialog.h"
@@ -18,11 +20,13 @@
 #include "debug_utils.h"
 #include "dialog_utils.h"
 #include "docwindow.h"
-#include "associationwidget.h"
 #include "floatingtextwidget.h"
 #include "notewidget.h"
+#include "object_factory.h"
 #include "idchangelog.h"
-#include "listpopupmenu.h"
+#include "menus/listpopupmenu.h"
+#include "port.h"
+#include "portwidget.h"
 #include "settingsdialog.h"
 #include "uml.h"
 #include "umldoc.h"
@@ -30,7 +34,10 @@
 #include "umlobject.h"
 #include "umlscene.h"
 #include "umlview.h"
+#include "usecase.h"
+#include "usecasewidget.h"
 #include "uniqueid.h"
+#include "widget_factory.h"
 
 // kde includes
 #include <KLocalizedString>
@@ -507,7 +514,6 @@ void UMLWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
     }
 
     QPointF delta = event->scenePos() - event->lastScenePos();
-    adjustUnselectedAssocs(delta.x(), delta.y());
 
     DEBUG(DBG_SRC) << "diffX=" << diffX << " / diffY=" << diffY;
     foreach(UMLWidget* widget, umlScene()->selectedWidgets()) {
@@ -830,12 +836,39 @@ void UMLWidget::slotMenuSelection(QAction *trigger)
         break;
     }
 
+    case ListPopupMenu::mt_Actor: {
+        UMLActor *actor = new UMLActor;
+        UMLWidget *widget = new ActorWidget(umlScene(), actor);
+        addConnectedWidget(widget, Uml::AssociationType::Association);
+        break;
+    }
+
     case ListPopupMenu::mt_Note: {
         NoteWidget *widget = new NoteWidget(umlScene());
         addConnectedWidget(widget, Uml::AssociationType::Anchor);
         break;
     }
 
+    case ListPopupMenu::mt_Port: {
+        // TODO: merge with ToolbarStateOneWidget::setWidget()
+        UMLPackage* component = umlObject()->asUMLPackage();
+        QString name = Model_Utils::uniqObjectName(UMLObject::ot_Port, component);
+        if (Dialog_Utils::askName(i18n("Enter Port Name"), i18n("Enter the port"), name)) {
+            UMLPort *port = Object_Factory::createUMLObject(UMLObject::ot_Port, name, component)->asUMLPort();
+            UMLWidget *umlWidget = Widget_Factory::createWidget(umlScene(), port);
+            umlWidget->setParentItem(this);
+            umlScene()->setupNewWidget(umlWidget);
+        }
+        break;
+    }
+
+    case ListPopupMenu::mt_UseCase: {
+        UMLUseCase *useCase = new UMLUseCase;
+        UMLWidget *widget = new UseCaseWidget(umlScene(), useCase);
+        addConnectedWidget(widget, Uml::AssociationType::Association);
+        break;
+    }
+
     default:
         WidgetBase::slotMenuSelection(trigger);
         break;
@@ -1142,6 +1175,10 @@ void UMLWidget::removeAssoc(AssociationWidget* pAssoc)
     if (pAssoc) {
         associationWidgetList().removeAll(pAssoc);
     }
+
+    if (changesShape()) {
+        updateGeometry();
+    }
 }
 
 /**
@@ -1152,6 +1189,7 @@ void UMLWidget::removeAssoc(AssociationWidget* pAssoc)
  */
 void UMLWidget::adjustAssocs(qreal dx, qreal dy)
 {
+    qDebug() << this;
     // don't adjust Assocs on file load, as
     // the original positions, which are stored in XMI
     // should be reproduced exactly
@@ -1631,8 +1669,10 @@ void UMLWidget::setSize(const QSizeF& size)
 
 /**
  * Update the size of this widget.
+ *
+ * @param withAssocs true - update associations too
  */
-void UMLWidget::updateGeometry()
+void UMLWidget::updateGeometry(bool withAssocs)
 {
     if (m_doc->loading()) {
         return;
@@ -1647,7 +1687,9 @@ void UMLWidget::updateGeometry()
     constrain(clipWidth, clipHeight);
     setSize(clipWidth, clipHeight);
     slotSnapToGrid();
-    adjustAssocs(size.width()-oldW, size.height()-oldH);
+    if (withAssocs)
+        adjustAssocs(size.width()-oldW, size.height()-oldH);
+    update();
 }
 
 /**
@@ -1969,7 +2011,7 @@ void UMLWidget::addConnectedWidget(UMLWidget *widget, Uml::AssociationType::Enum
 /**
  * Adds a widget to the diagram, which is connected to the current widget
  * @param widget widget instance to add to diagram
- * @param type association type
+ * @param showProperties whether to show properties of the widget
  */
 void UMLWidget::addWidget(UMLWidget *widget, bool showProperties)
 {
