@@ -12,12 +12,14 @@
 
 #include "classifier.h"
 #include "debug_utils.h"
+#include "dialog_utils.h"
 #include "floatingtextwidget.h"
-#include "optionstate.h"
 #include "uml.h"
 #include "umldoc.h"
+#include "umllistview.h"
 #include "umlobject.h"
 #include "umlscene.h"
+#include "widgetbasepopupmenu.h"
 
 #if QT_VERSION < 0x050000
 #include <kcolordialog.h>
@@ -54,9 +56,10 @@ WidgetBase::WidgetBase(UMLScene *scene, WidgetType type)
     m_usesDiagramLineWidth(true),
     m_usesDiagramTextColor(true),
     m_usesDiagramUseFillColor(true),
-    m_autoResize(true)
+    m_autoResize(true),
+    m_changesShape(false)
 {
-    Q_ASSERT(m_baseType > wt_MIN && m_baseType < wt_MAX);
+    Q_ASSERT(m_baseType > wt_Min && m_baseType < wt_Max);
     // Note: no virtual methods from derived classes available,
     // this operation need to be finished in derived class constructor.
     setLineColor(QColor("black"));
@@ -91,7 +94,7 @@ WidgetBase::~WidgetBase()
  */
 WidgetBase::WidgetType WidgetBase::baseType() const
 {
-    Q_ASSERT(m_baseType > wt_MIN && m_baseType < wt_MAX);
+    Q_ASSERT(m_baseType > wt_Min && m_baseType < wt_Max);
     return m_baseType;
 }
 
@@ -100,7 +103,7 @@ WidgetBase::WidgetType WidgetBase::baseType() const
  */
 void WidgetBase::setBaseType(const WidgetType& baseType)
 {
-    Q_ASSERT(baseType > wt_MIN && baseType < wt_MAX);
+    Q_ASSERT(baseType > wt_Min && baseType < wt_Max);
     m_baseType = baseType;
 }
 
@@ -109,7 +112,7 @@ void WidgetBase::setBaseType(const WidgetType& baseType)
  */
 QLatin1String WidgetBase::baseTypeStr() const
 {
-    Q_ASSERT(m_baseType > wt_MIN && m_baseType < wt_MAX);
+    Q_ASSERT(m_baseType > wt_Min && m_baseType < wt_Max);
     return QLatin1String(ENUM_NAME(WidgetBase, WidgetType, m_baseType));
 }
 
@@ -496,12 +499,37 @@ void WidgetBase::setAutoResize(bool state)
     m_autoResize = state;
 }
 
+/**
+ * Return changes state property
+ * @return the changes shape state
+ */
+bool WidgetBase::changesShape()
+{
+    return m_changesShape;
+}
+
+/**
+ * set changes shape property
+ * @param state
+ */
+void WidgetBase::setChangesShape(bool state)
+{
+    m_changesShape = state;
+}
+
 /**
  * A virtual method for the widget to display a property dialog box.
  * Subclasses should reimplment this appropriately.
+ * In case the user cancels the dialog or there are some requirements
+ * not fulfilled the method returns false; true otherwise.
+ *
+ * @return true - properties has been applyed
+ * @return false - properties has not been applied
+ *
  */
-void WidgetBase::showPropertiesDialog()
+bool WidgetBase::showPropertiesDialog()
 {
+    return false;
 }
 
 /**
@@ -765,7 +793,7 @@ void WidgetBase::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
     // Determine multi state
     bool multi = (isSelected() && count > 1);
 
-    ListPopupMenu popup(0, this, multi, scene->getUniqueSelectionType());
+    WidgetBasePopupMenu popup(0, this, multi, scene->getUniqueSelectionType());
 
     // Disable the "view code" menu for simple code generators
     if (UMLApp::app()->isSimpleCodeGeneratorActive()) {
@@ -773,21 +801,7 @@ void WidgetBase::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
     }
 
     QAction *triggered = popup.exec(event->screenPos());
-    ListPopupMenu *parentMenu = ListPopupMenu::menuFromAction(triggered);
-
-    if (!parentMenu) {
-        uDebug() << "Action's data field does not contain ListPopupMenu pointer";
-        return;
-    }
-
-    WidgetBase *ownerWidget = parentMenu->ownerWidget();
-    // assert because logic is based on only WidgetBase being the owner of
-    // ListPopupMenu actions executed in this context menu.
-    Q_ASSERT_X(ownerWidget != 0, "WidgetBase::contextMenuEvent",
-            "ownerWidget is null which means action belonging to UMLView, UMLScene"
-            " or UMLObject is the one triggered in ListPopupMenu");
-
-    ownerWidget->slotMenuSelection(triggered);
+    slotMenuSelection(triggered);
 }
 
 /**
@@ -945,7 +959,13 @@ void WidgetBase::slotMenuSelection(QAction *trigger)
         break;
     }
 
+    case ListPopupMenu::mt_Remove:
+        umlScene()->deleteSelection();
+        break;
+
     case ListPopupMenu::mt_Delete:
+        if (!Dialog_Utils::askDeleteAssociation())
+            break;
         umlScene()->deleteSelection();
         break;
 
@@ -1292,7 +1312,6 @@ Icon_Utils::IconType WidgetBase::toIcon(WidgetBase::WidgetType wt)
 #include  "regionwidget.h"
 #include  "signalwidget.h"
 #include  "statewidget.h"
-#include  "floatingtextwidget.h"
 #include  "usecasewidget.h"
 
 ActivityWidget* WidgetBase::asActivityWidget() { return dynamic_cast<ActivityWidget* >(this); }
